onStreamSourceReady property
Callback when the virtual stream source is ready This provides the VirtualStreamSource that can be used to create a processed MediaStream for transport
Implementation
final void Function(VirtualStreamSource source)? onStreamSourceReady;