isSupported property
bool
get
isSupported
Whether wake lock is supported on the current platform
Implementation
static bool get isSupported =>
!kIsWeb && (Platform.isIOS || Platform.isAndroid);
Whether wake lock is supported on the current platform
static bool get isSupported =>
!kIsWeb && (Platform.isIOS || Platform.isAndroid);