BackgroundSegmenter class abstract

Legacy abstract interface for backward compatibility.

@deprecated Use BackgroundSegmenterBase from segmenter/segmenter.dart instead. This interface is kept for backward compatibility with existing code.

Implementers

Constructors

BackgroundSegmenter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isReady → bool
Check if the segmenter is ready
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
Dispose of resources
initialize() → Future<void>
Initialize the segmenter
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processFrame(Uint8List frameData, {required int width, required int height}) → Future<SegmentationResult>
Process a frame and return the segmented result
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isPlatformSupported → bool
Check if this platform is supported Supported platforms:
no setter