CoHostModalOptions class

Configuration options for the CoHostModal widget.

Example:

CoHostModal(
  options: CoHostModalOptions(
    isCoHostModalVisible: true,
    onCoHostClose: () {
      // Logic for closing the modal
    },
    participants: participantsList,
    coHostResponsibility: responsibilitiesList,
    roomName: "MyRoom",
    socket: mySocket,
    updateCoHostResponsibility: (newResponsibilities) => print(newResponsibilities),
    updateCoHost: (coHost) => print("Updated co-host: $coHost"),
    updateIsCoHostModalVisible: (isVisible) => print("Modal visibility: $isVisible"),
  ),
);

Constructors

CoHostModalOptions({required bool isCoHostModalVisible, required VoidCallback onCoHostClose, ModifyCoHostSettingsType onModifyCoHostSettings = modifyCoHostSettings, String currentCohost = 'No coHost', required List<Participant> participants, required List<CoHostResponsibility> coHostResponsibility, String position = 'topRight', Color backgroundColor = const Color.fromARGB(255, 179, 214, 237), required String roomName, ShowAlert? showAlert, required dynamic updateCoHostResponsibility(List<CoHostResponsibility>), required dynamic updateCoHost(String), required dynamic updateIsCoHostModalVisible(bool), Socket? socket, ModalRenderMode renderMode = ModalRenderMode.modal})

Properties

backgroundColor Color
Background color of the modal.
final
coHostResponsibility List<CoHostResponsibility>
List of co-host responsibilities.
final
currentCohost String
Current co-host name.
final
hashCode int
The hash code for this object.
no setterinherited
isCoHostModalVisible bool
Determines if the co-host modal is visible.
final
onCoHostClose VoidCallback
Function to handle closing the co-host modal.
final
onModifyCoHostSettings ModifyCoHostSettingsType
Function to modify co-host settings.
final
participants List<Participant>
List of participants in the meeting.
final
position String
Position of the modal ('topLeft', 'topRight', 'bottomLeft', 'bottomRight').
final
renderMode ModalRenderMode
Render mode for embedding in different contexts.
final
roomName String
Name of the room.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAlert ShowAlert?
Function to display alerts.
final
socket → Socket?
Socket instance for real-time communication.
final
updateCoHost → dynamic Function(String)
Update function for co-host.
final
updateCoHostResponsibility → dynamic Function(List<CoHostResponsibility>)
Update function for co-host responsibilities.
final
updateIsCoHostModalVisible → dynamic Function(bool)
Update function for co-host modal visibility.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited