PreJoinPageOptions class

Constructors

PreJoinPageOptions({String? localLink, bool connectMediaSFU = true, required PreJoinPageParameters parameters, required Credentials credentials, PreJoinPageType? customBuilder, bool? returnUI = true, CreateMediaSFURoomOptions? noUIPreJoinOptionsCreate, JoinMediaSFURoomOptions? noUIPreJoinOptionsJoin, CreateRoomOnMediaSFUType? createMediaSFURoom = createRoomOnMediaSFU, JoinRoomOnMediaSFUType? joinMediaSFURoom = joinRoomOnMediaSFU, String? localAppKey, String? localApiUserName, String? localApiKey, String? localSubUserName, bool? useFixedLink, String? initialMeetingId, VoidCallback? onBack})

Properties

connectMediaSFU bool
final
createMediaSFURoom CreateRoomOnMediaSFUType?
getter/setter pair
credentials Credentials
final
customBuilder PreJoinPageType?
final
hashCode int
The hash code for this object.
no setterinherited
initialMeetingId String?
Initial meeting ID to pre-fill in the prejoin form Used for deep links like /meeting/:roomId
final
joinMediaSFURoom JoinRoomOnMediaSFUType?
getter/setter pair
localApiKey String?
API key for backend authentication in socket handshake Used when connecting to local backend via localLink
final
localApiUserName String?
API username for backend authentication in socket handshake Used when connecting to local backend via localLink
final
localAppKey String?
App key for Flutter app authentication in socket handshake (X-App-Key) Used when connecting to local backend via localLink
final
final
localSubUserName String?
Sub-username for organization/team member identification Used for subuser accounts within an organization
final
noUIPreJoinOptionsCreate CreateMediaSFURoomOptions?
getter/setter pair
noUIPreJoinOptionsJoin JoinMediaSFURoomOptions?
getter/setter pair
onBack VoidCallback?
Optional callback for navigating back from the prejoin page. When provided, the prejoin page will use this instead of Navigator.maybePop. Useful for apps using GoRouter or other routing packages.
final
parameters PreJoinPageParameters
final
returnUI bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Whether to use fixed link (stagerooms.mediasfu.com) instead of dynamic URL selection When true, always connects to stagerooms.mediasfu.com When false, URL is selected based on meeting ID prefix (d=demos, s=sandbox, p=production)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited