localAppKey property
App key for Flutter app authentication in socket handshake (X-App-Key) Used when connecting to local backend via localLink
Implementation
final String? localAppKey;
App key for Flutter app authentication in socket handshake (X-App-Key) Used when connecting to local backend via localLink
final String? localAppKey;