useFixedLink property

bool? useFixedLink
final

Whether to use a fixed room host instead of meeting-based URL selection. Use this only when your deployment requires a single fixed entry host.

Implementation

final bool? useFixedLink;