PremiumIconButton class

A circular icon button with premium styling.

Inheritance

Constructors

PremiumIconButton({Key? key, required IconData icon, VoidCallback? onPressed, double size = 44, double? iconSize, Color? backgroundColor, Color? iconColor, PremiumButtonVariant variant = PremiumButtonVariant.filled, bool isDarkMode = true, bool isDisabled = false, String? tooltip, bool hapticFeedback = true})
const

Properties

backgroundColor Color?
Background color.
final
hapticFeedback bool
Whether to enable haptic feedback.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
The icon to display.
final
iconColor Color?
Icon color.
final
iconSize double?
Icon size.
final
isDarkMode bool
Whether to use dark mode.
final
isDisabled bool
Whether the button is disabled.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed VoidCallback?
Callback when button is pressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
Size of the button.
final
tooltip String?
Tooltip text.
final
variant PremiumButtonVariant
Style variant.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PremiumIconButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited