components_modern/core/widgets/premium_text_field library

Classes

PremiumSearchField
A premium search field with animated clear button and search icon.
PremiumTextField
A premium text field with modern styling and animations.

Enums

PremiumTextFieldVariant
Style variants for PremiumTextField.