SkeletonCard class

A skeleton card layout preset.

Inheritance

Constructors

SkeletonCard({Key? key, bool showAvatar = true, double avatarSize = 40, int textLines = 2, bool showImage = false, double imageHeight = 120, double borderRadius = 16, EdgeInsetsGeometry? padding, bool isLoading = true})
const

Properties

avatarSize double
Avatar size.
final
borderRadius double
Border radius.
final
hashCode int
The hash code for this object.
no setterinherited
imageHeight double
Height of the image area.
final
isLoading bool
Whether loading.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
Padding inside the card.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAvatar bool
Whether to show an avatar.
final
showImage bool
Whether to show an image area.
final
textLines int
Number of text lines.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited