ConfigureWhiteboardModalOptions class

Options for the ConfigureWhiteboardModal widget.

Constructors

ConfigureWhiteboardModalOptions({required bool isVisible, required VoidCallback onClose, required ConfigureWhiteboardModalParameters parameters, Color backgroundColor = const Color(0xFFF5F5F5), String position = 'topRight', ModalRenderMode renderMode = ModalRenderMode.modal, bool isDarkMode = false, bool enableGlassmorphism = true})

Properties

backgroundColor Color
final
enableGlassmorphism bool
final
hashCode int
The hash code for this object.
no setterinherited
isDarkMode bool
final
isVisible bool
final
onClose VoidCallback
final
parameters ConfigureWhiteboardModalParameters
final
position String
final
renderMode ModalRenderMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited