ScreenboardModalOptions class

Options for configuring the ScreenboardModal.

Constructors

ScreenboardModalOptions({required ScreenboardModalParameters parameters, required bool isVisible, required VoidCallback onClose, String position = 'topRight', Color backgroundColor = const Color(0xFF83C0E9)})

Properties

backgroundColor Color
Background color of the modal.
final
hashCode int
The hash code for this object.
no setterinherited
isVisible bool
Whether the modal is visible.
final
onClose VoidCallback
Callback when the modal is closed.
final
parameters ScreenboardModalParameters
Parameters containing state and callbacks.
final
position String
Position of the modal on screen.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited