WhiteboardOptions class

Options for configuring the Whiteboard widget.

Constructors

WhiteboardOptions({required double customWidth, required double customHeight, required WhiteboardParameters parameters, bool showAspect = true})

Properties

customHeight double
Height of the whiteboard canvas.
final
customWidth double
Width of the whiteboard canvas.
final
hashCode int
The hash code for this object.
no setterinherited
parameters WhiteboardParameters
Whiteboard parameters containing state and callbacks.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAspect bool
Whether to show aspect ratio indicator.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited