AutoAdjustOptions class
Options for adjusting values based on various parameters.
Contains properties such as the number of participants, the event type, and flags for screen sharing status.
Constructors
- AutoAdjustOptions({required int n, required EventType eventType, bool whiteboardStarted = false, bool whiteboardEnded = false})
Properties
- eventType → EventType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- n → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
-
final
- whiteboardEnded → bool
-
final
- whiteboardStarted → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited