CheckPermissionOptions class
Options for checking permission based on specific settings.
Contains settings for audio, video, screenshare, and chat, as well as the type of permission to check. Optionally supports per-level permission configuration via permissionConfig and participantLevel.
Constructors
- CheckPermissionOptions({required String audioSetting, required String videoSetting, required String chatSetting, required String permissionType, PermissionConfig? permissionConfig, String? participantLevel})
Properties
- audioSetting → String
-
final
- chatSetting → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- participantLevel → String?
-
final
- permissionConfig → PermissionConfig?
-
final
- permissionType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- videoSetting → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited