PermissionCapabilities class

Configuration for what each permission level can do. Each capability can be: "allow" | "approval" | "disallow"

Constructors

PermissionCapabilities({required String useMic, required String useCamera, required String useScreen, required String useChat})
PermissionCapabilities.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useCamera String
final
useChat String
final
useMic String
final
useScreen String
final

Methods

copyWith({String? useMic, String? useCamera, String? useScreen, String? useChat}) PermissionCapabilities
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited