CheckLimitsAndMakeRequestOptions class

CheckLimitsAndMakeRequestOptions

Encapsulates the parameters required for rate limiting and request handling.

Constructors

CheckLimitsAndMakeRequestOptions({required String apiUserName, required String apiToken, required String link, required String userName, required PreJoinPageParameters parameters, bool validate = true})

Properties

apiToken → String
final
apiUserName → String
final
hashCode → int
The hash code for this object.
no setterinherited
final
parameters → PreJoinPageParameters
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userName → String
final
validate → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited