ScreenShareState class

Which screen share to render, and whose it is.

Constructors

ScreenShareState({MediaStream? stream, bool isLocal = false, String name = ''})
const

Properties

active bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isLocal bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream MediaStream?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited