ModerationPermissions class

Constructors

ModerationPermissions({required bool isHost, required bool isCoHost, required bool canControlMedia, required bool canManageParticipants, required bool canManageChat, required bool canManageWaitingRoom})
const

Properties

canControlMedia bool
final
canManageChat bool
final
canManageParticipants bool
final
canManageWaitingRoom bool
final
hashCode int
The hash code for this object.
no setterinherited
isCoHost bool
final
isHost bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited