ChatMessage class

Constructors

ChatMessage({required String sender, required String message, required String timestamp, required List<String> receivers, required bool direct, required bool mine})
const

Properties

direct bool
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
mine bool
final
receivers List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender String
final
timestamp String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited