PendingApprovals class

Constructors

PendingApprovals({required List<PendingApprovalPerson> waiting, required List<PendingApprovalPerson> requests})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requests List<PendingApprovalPerson>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
no setter
waiting List<PendingApprovalPerson>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited