FocusModeState class

Constructors

FocusModeState({required bool active, required List<Participant> panelists, required bool selfIsPanelist, required bool mutesMicrophones, required bool mutesCameras})
const

Properties

active bool
final
hashCode int
The hash code for this object.
no setterinherited
mutesCameras bool
final
mutesMicrophones bool
final
panelists List<Participant>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfIsPanelist bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited