RecordingNoticeState class

Constructors

RecordingNoticeState({required String message, required String elapsed, required int elapsedSeconds, required bool canPauseResume, required int pausesUsed, required int pauseLimit})
const

Properties

canPauseResume bool
final
elapsed String
final
elapsedSeconds int
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
pauseLimit int
final
pauseLimitReached bool
no setter
pausesUsed int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited