TranslationState class
Constructors
-
TranslationState({required String? globalLanguage, required List<
TranslationPreference> perSpeaker, required bool active, required List<String> availableLanguages}) -
const
Properties
- active → bool
-
final
-
availableLanguages
→ List<
String> -
final
- globalLanguage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
perSpeaker
→ List<
TranslationPreference> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited