BreakoutState class

Constructors

BreakoutState({required bool active, required bool canStart, required List<List> rooms, required int currentRoom})
const

Properties

active bool
final
canStart bool
final
currentRoom int
final
hashCode int
The hash code for this object.
no setterinherited
rooms List<List>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited