RecordingState class

Constructors

RecordingState({required RecordingStatus status, required bool active, required bool canRecord, required String mediaOptions, required int elapsedSeconds})
const

Properties

active → bool
final
canRecord → bool
final
elapsedSeconds → int
final
hashCode → int
The hash code for this object.
no setterinherited
mediaOptions → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → RecordingStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited