WhiteboardState class

Constructors

WhiteboardState({required bool active, required bool canStart, required List<WhiteboardUser> users, required int limit, dynamic canvas})
const

Properties

active bool
final
canStart bool
final
canvas → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
limit int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users List<WhiteboardUser>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited