ViewerSessionIdentity class

Constructors

ViewerSessionIdentity({required String viewerId, required String roomName, String? playbackUrl, String? protocol, String? token, Map<String, dynamic> metadata = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
final
playbackUrl String?
final
protocol String?
final
roomName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
final
viewerId String
final

Methods

copyWith({String? playbackUrl}) ViewerSessionIdentity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited