ViewerSessionProvider class
Constructors
- ViewerSessionProvider({required JoinViewerSession join, HeartbeatViewerSession? heartbeat, RequestViewerPromotion? requestPromotion, PollViewerSession? poll, LeaveViewerSession? leave})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heartbeat → HeartbeatViewerSession?
-
final
- join → JoinViewerSession
-
final
- leave → HeartbeatViewerSession?
-
final
- poll → PollViewerSession?
-
final
- requestPromotion → HeartbeatViewerSession?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited