ViewerSessionSnapshot class

Constructors

ViewerSessionSnapshot({required ViewerSessionPhase phase, required ViewerSessionIdentity? session, required ViewerSessionStatus? status, required String error, required bool canRequestPromotion})
const

Properties

canRequestPromotion bool
final
error String
final
hashCode int
The hash code for this object.
no setterinherited
phase ViewerSessionPhase
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session ViewerSessionIdentity?
final
status ViewerSessionStatus?
final

Methods

copyWith({ViewerSessionPhase? phase, ViewerSessionIdentity? session, ViewerSessionStatus? status, String? error}) ViewerSessionSnapshot
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited