MediasfuFeature enum

Enum representing the various features that may have platform-specific support.

Inheritance
Available extensions

Values

screenboard → const MediasfuFeature

Screen annotation/screenboard feature (web only).

virtualBackgrounds → const MediasfuFeature

Virtual backgrounds feature (iOS, Android, macOS, Windows).

screenShare → const MediasfuFeature

Screen sharing feature (all platforms with platform-specific implementations).

whiteboard → const MediasfuFeature

Whiteboard feature (all platforms).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MediasfuFeature>
A constant List of the values in this enum, in order of their declaration.