VoiceCloneConfig class

Voice clone configuration

Constructors

VoiceCloneConfig({required String provider, required String voiceId, double? stability, double? similarity})
const
VoiceCloneConfig.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
provider String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
similarity double?
final
stability double?
final
voiceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited