TranslationChannelsAvailableOptions class

Constructors

TranslationChannelsAvailableOptions({required TranslationChannelsAvailableData data, void updateAvailableTranslationChannels(String speakerId, List<String> languages, String originalProducerId)?, String? myDefaultListenLanguage, dynamic socket, String? roomName})

Properties

data TranslationChannelsAvailableData
final
hashCode int
The hash code for this object.
no setterinherited
myDefaultListenLanguage String?
final
roomName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socket → dynamic
final
updateAvailableTranslationChannels → void Function(String speakerId, List<String> languages, String originalProducerId)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited