TranslationMemberStateData class

Constructors

TranslationMemberStateData({required String memberId, String? memberName, required Map<String, dynamic> state})
TranslationMemberStateData.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
memberId String
final
memberName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited