TranslationSpeakerOutputChangedData class

Constructors

TranslationSpeakerOutputChangedData({required String speakerId, required String speakerName, required String inputLanguage, String? outputLanguage, required String originalProducerId, required bool enabled})
TranslationSpeakerOutputChangedData.fromMap(Map<String, dynamic> map)
factory

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
inputLanguage String
final
originalProducerId String
final
outputLanguage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speakerId String
final
speakerName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited