TranslationSpeakerOutputChangedOptions class
Constructors
-
TranslationSpeakerOutputChangedOptions({required TranslationSpeakerOutputChangedData data, Future<
void> pauseOriginalProducer(String originalProducerId, String speakerId)?, Future<void> resumeOriginalProducer(String originalProducerId, String speakerId)?, Future<void> stopConsumingTranslationForSpeaker(String speakerId)?, void updateSpeakerTranslationState(String speakerId, String? outputLanguage, String originalProducerId)?, ShowAlert? showAlert, ListenerOverride? listenerOverride})
Properties
- data → TranslationSpeakerOutputChangedData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- listenerOverride → ListenerOverride?
-
final
-
pauseOriginalProducer
→ Future<
void> Function(String originalProducerId, String speakerId)? -
final
-
resumeOriginalProducer
→ Future<
void> Function(String originalProducerId, String speakerId)? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAlert → ShowAlert?
-
final
-
stopConsumingTranslationForSpeaker
→ Future<
void> Function(String speakerId)? -
final
- updateSpeakerTranslationState → void Function(String speakerId, String? outputLanguage, String originalProducerId)?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited