TranslationSubscribedData class

Constructors

TranslationSubscribedData({required String speakerId, String? speakerName, required String language, required bool channelCreated, String? producerId, String? originalProducerId})
TranslationSubscribedData.fromMap(Map<String, dynamic> map)
factory

Properties

channelCreated bool
final
hashCode int
The hash code for this object.
no setterinherited
language String
final
originalProducerId String?
final
producerId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speakerId String
final
speakerName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited