ResponseLocalConnectionData class

Data received during local socket connection.

Constructors

ResponseLocalConnectionData({required String socketId, required String mode, String? apiUserName, String? apiKey, required bool allowRecord, required MeetingRoomParams eventRoomParams, required RecordingParams recordingParams})
ResponseLocalConnectionData.fromMap(Map<String, dynamic> map)
Converts a map into a ResponseLocalConnectionData object.
factory

Properties

allowRecord → bool
final
apiKey → String?
final
apiUserName → String?
final
eventRoomParams → MeetingRoomParams
final
hashCode → int
The hash code for this object.
no setterinherited
mode → String
final
recordingParams → RecordingParams
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited