OverlayPositionStyle class

Constructors

OverlayPositionStyle({double? top, double? left, double? right, double? bottom})
OverlayPositionStyle.fromMap(Map<String, double?> map)
factory

Properties

bottom ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
left ↔ double?
getter/setter pair
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, double?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited