ShapePayload class

Constructors

ShapePayload({required String type, required double x1, required double y1, required double x2, required double y2, required String color, required double thickness, required String lineType})
ShapePayload.fromMap(Map<String, dynamic> map)
factory

Properties

color → String
final
hashCode → int
The hash code for this object.
no setterinherited
lineType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double
final
type → String
final
x1 → double
final
x2 → double
final
y1 → double
final
y2 → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String key) → dynamic
operator []=(String key, dynamic value) → void