TranslationMeta class

Metadata for translation producers.

Constructors

TranslationMeta({required String speakerId, required String language, required String originalProducerId, bool? isSpeakerControlled})
TranslationMeta.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSpeakerControlled → bool?
final
language → String
final
originalProducerId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speakerId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited