BackgroundModalParameters class abstract
Parameters for the BackgroundModal widget.
- Implementers
Constructors
Properties
- frameRate → int
-
Target frame rate for camera preview
no setter
- getUpdatedAllParams → BackgroundModalParameters Function()
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkModeValue → bool
-
Whether the app is in dark mode (for theme awareness)
no setter
- localStreamVideo → MediaStream?
-
The current local video stream from the main app.
This is used for preview instead of creating a new camera stream.
Mirrors React's localStreamVideo parameter.
no setter
-
onBackgroundApply
→ Future<
void> Function(VirtualBackground)? -
Callback when background is applied
no setter
-
onBackgroundPreview
→ Future<
void> Function(VirtualBackground)? -
Callback when background is previewed (before apply)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedBackground → VirtualBackground?
-
no setter
- showAlert → ShowAlert?
-
no setter
- targetResolution → String
-
no setter
- updateAppliedBackground → void Function(bool)
-
Callback to update appliedBackground flag
Set to true when a background has been successfully applied
no setter
- updateBackgroundHasChanged → void Function(bool)
-
Callback to mark that background has changed
no setter
- updateIsBackgroundModalVisible → void Function(bool)
-
no setter
- updateKeepBackground → void Function(bool)
-
Callback to update keepBackground flag
Set to true when virtual background processing is active
no setter
- updateProcessedStream → void Function(MediaStream?)?
-
Callback to update the processed stream for virtual background
This mirrors React's updateProcessedStream
no setter
- updateSelectedBackground → void Function(VirtualBackground?)
-
no setter
- vidCons → dynamic
-
Video constraints for camera initialization when videoAlreadyOn is false
Can be
VidConstype orMap<String, dynamic>no setter - videoAlreadyOn → bool
-
Whether the video is already on (camera already streaming)
When false, the modal will initialize its own camera for preview
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited