localStreamVideo property
MediaStream?
get
localStreamVideo
The current local video stream from the main app. This is used for preview instead of creating a new camera stream. Mirrors React's localStreamVideo parameter.
Implementation
MediaStream? get localStreamVideo;