onBack property
Optional callback for navigating back from the prejoin page. When provided, the prejoin page will use this instead of Navigator.maybePop. Useful for apps using GoRouter or other routing packages.
Implementation
final VoidCallback? onBack;