useFixedLink property
Whether to use a fixed room host instead of meeting-based URL selection. Use this only when your deployment requires a single fixed entry host.
Implementation
final bool? useFixedLink;
Whether to use a fixed room host instead of meeting-based URL selection. Use this only when your deployment requires a single fixed entry host.
final bool? useFixedLink;