TranslationConsumerSwitchParameters class abstract
Parameters for translation consumer switch operations
Constructors
Properties
- breakOutRoomEnded → bool
-
no setter
-
breakoutRooms
→ List<
List< ?BreakoutParticipant> > -
no setter
- breakOutRoomStarted → bool
-
no setter
-
consumerTransports
→ List<
TransportType> -
no setter
- eventType → EventType
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostNewRoom → int?
-
no setter
- islevel → String
-
no setter
-
limitedBreakRoom
→ List<
BreakoutParticipant> ? -
no setter
- member → String
-
no setter
-
participants
→ List<
Participant> -
no setter
-
refParticipants
→ List<
Participant> ? -
no setter
- roomName → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
updateConsumerTransports
→ void Function(List<
TransportType> ) -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → dynamic