BulkUpdateParticipantPermissionsOptions class
Constructors
-
BulkUpdateParticipantPermissionsOptions({required Socket socket, required List<
Participant> participants, required String newLevel, required String member, required String islevel, required String roomName, ShowAlert? showAlert, int maxBatchSize = 50})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- islevel → String
-
final
- maxBatchSize → int
-
final
- member → String
-
final
- newLevel → String
-
final
-
participants
→ List<
Participant> -
final
- roomName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAlert → ShowAlert?
-
final
- socket → Socket
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited