ModerationParameters class abstract
- Implementers
Constructors
Properties
- coHost → String
-
no setter
-
coHostResponsibility
→ List<
CoHostResponsibility> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- islevel → String
-
no setter
- member → String
-
no setter
-
participants
→ List<
Participant> -
no setter
-
participantsAll
→ List<
Participant> -
no setter
-
requestList
→ List<
Request> -
no setter
- roomName → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAlert → ShowAlert?
-
no setter
- socket → Socket?
-
no setter
- updateCoHost → void Function(String)
-
no setter
-
updateCoHostResponsibility
→ void Function(List<
CoHostResponsibility> ) -
no setter
- updateIsCoHostModalVisible → void Function(bool)
-
no setter
-
updateParticipants
→ void Function(List<
Participant> ) -
no setter
-
updateRequestList
→ void Function(List<
Request> ) -
no setter
-
updateWaitingRoomList
→ void Function(List<
WaitingRoomParticipant> ) -
no setter
-
waitingRoomList
→ List<
WaitingRoomParticipant> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited