RecordingCapabilities class
Constructors
Properties
- allParticipants → bool
-
final
- audio → bool
-
final
- audioPeopleLimit → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hls → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- video → bool
-
final
- videoParticipants → bool
-
final
- videoPeopleLimit → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited