VirtualBackgroundState class
Constructors
- VirtualBackgroundState({required bool active, required MediaStream? stream, required bool applied, required String? selectedImage})
-
const
Properties
- active → bool
-
final
- applied → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedImage → String?
-
final
- stream → MediaStream?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited