ViewerSessionHandle class
Constructors
- ViewerSessionHandle({required ViewerSessionProvider provider, required String roomName, String? displayName, Duration pollInterval = const Duration(seconds: 5), Duration heartbeatInterval = const Duration(seconds: 30), void onChange(ViewerSessionSnapshot)?})
Properties
- displayName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heartbeatInterval → Duration
-
final
- onChange → void Function(ViewerSessionSnapshot)?
-
final
- pollInterval → Duration
-
final
- provider → ViewerSessionProvider
-
final
- roomName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshot → ViewerSessionSnapshot
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPromotion(
) → Future< ViewerSessionSnapshot> -
start(
) → Future< ViewerSessionSnapshot> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited