ScreenAnnotationCapture class
Stub implementation for non-web platforms.
On non-web platforms, direct canvas-to-MediaStream capture is not available. The annotation broadcasting feature is only supported on web.
Constructors
Properties
- annotationCanvas → dynamic
-
The annotation canvas (null on non-web)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
no setter
- isCapturing → bool
-
Whether capture is active (always false on non-web)
no setter
- processedStream → MediaStream?
-
The combined MediaStream (always null on non-web)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
Canvas dimensions
no setter
Methods
-
clearAnnotationCanvas(
) → void - Clear annotation canvas (no-op on non-web)
-
dispose(
) → void - Dispose (no-op on non-web)
-
drawToAnnotationCanvas(
{required String type, required double x1, required double y1, required double x2, required double y2, required String color, required double thickness, String lineType = 'solid', List< Map< ? freehandPoints}) → voidString, dynamic> > - Draw to annotation canvas (no-op on non-web)
-
initialize(
MediaStream localStreamScreen) → Future - Initialize (returns null on non-web as annotation broadcasting is not supported)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redrawShapes(
List< Map< shapes) → voidString, dynamic> > - Redraw shapes (no-op on non-web)
-
startCapture(
{int frameRate = 30}) → Future< MediaStream?> - Start capture (returns null on non-web)
-
stopCapture(
) → void - Stop capture (no-op on non-web)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited