WebCanvasCapture class
Legacy class for backward compatibility. Prefer using ScreenAnnotationCapture for the React-style implementation.
- Annotations
-
- @Deprecated('Use ScreenAnnotationCapture instead')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCapturing → bool
-
no setter
- mediaStream → MediaStream?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited