launchConfigureWhiteboard function
Toggles the visibility of the configure whiteboard modal.
This function is typically called when the host wants to start, configure, or end a whiteboard session. Only hosts (level 2) can access this functionality.
Example:
launchConfigureWhiteboard(
LaunchConfigureWhiteboardOptions(
updateIsConfigureWhiteboardModalVisible: updateIsConfigureWhiteboardModalVisible,
isConfigureWhiteboardModalVisible: false,
),
);
Implementation
void launchConfigureWhiteboard(LaunchConfigureWhiteboardOptions options) {
// Toggle the visibility of the configure whiteboard modal
options.updateIsConfigureWhiteboardModalVisible(
!options.isConfigureWhiteboardModalVisible);
}