TranslationSubscribedOptions class
Constructors
-
TranslationSubscribedOptions({required TranslationSubscribedData data, void updateListenPreferences(Map<
String, String> (Map<String, String> ))?, void updateTranslationProducerMap(TranslationProducerMap (TranslationProducerMap))?, Future<void> startConsumingTranslation(String producerId, String speakerId, String language, String originalProducerId)?, ShowAlert? showAlert})
Properties
- data → TranslationSubscribedData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAlert → ShowAlert?
-
final
-
startConsumingTranslation
→ Future<
void> Function(String producerId, String speakerId, String language, String originalProducerId)? -
final
-
updateListenPreferences
→ void Function(Map<
String, String> (Map<String, String> ))? -
final
- updateTranslationProducerMap → void Function(TranslationProducerMap (TranslationProducerMap))?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited