ConnectLocalSocketOptions class

Options for connecting to a local socket. Supports optional authentication parameters for backend handshake.

Constructors

ConnectLocalSocketOptions({required String link, String? appKey, String? apiUserName, String? apiKey})

Properties

apiKey String?
Optional API key for backend authentication
final
apiUserName String?
Optional API username for backend authentication
final
appKey String?
Optional app key for Flutter app authentication (X-App-Key)
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited